pygeoip.const

Package pygeoip :: Module const |
[frames] | no frames]

# Module const

source code

Constants for the database parser

Authors:
  Jennifer Ennis <zaylea@gmail.com>, William Tisäter <william@defunct.cc>

License: Copyright(C) 2004 MaxMind LLC

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this program. If not, see <http://www.gnu.org/licenses/lgpl.txt>.

Variables
| PY2 = `True`
| PY3 = `False`
| GEOIP_STANDARD = `0`
| GEOIP_MEMORY_CACHE = `1`
| DMA_MAP = ``{`500`:` `'``Portland-Auburn, ME``'``,` 501`:` `'``New York, NY``'``,` 50`...``
| COUNTRY_CODES = ``(``'````'``,` `'``AP``'``,` `'``EU``'``,` `'``AD``'``,` `'``AE``'``,` `'``AF``'``,` `'``AG``'``,` `'``AI``'``,``...``
| COUNTRY_CODES3 = ``(``'````'``,` `'``AP``'``,` `'``EU``'``,` `'``AND``'``,` `'``ARE``'``,` `'``AFG``'``,` `'``ATG``'``,` `...``
| COUNTRY_NAMES = ``(``'````'``,` `'``Asia/Pacific Region``'``,` `'``Europe``'``,` `'``Andorra``...``
| CONTINENT_NAMES = ``(``'``--``'``,` `'``AS``'``,` `'``EU``'``,` `'``EU``'``,` `'``AS``'``,` `'``AS``'``,` `'``NA``'``,` `'``...``
| STANDARD = `0`
| MEMORY_CACHE = `1`
| MMAP_CACHE = `8`
| COUNTRY_BEGIN = `16776960`
| STATE_BEGIN_REV0 = `16700000`
| STATE_BEGIN_REV1 = `16000000`
| STRUCTURE_INFO_MAX_SIZE = `20`
| DATABASE_INFO_MAX_SIZE = `100`
| COUNTRY_EDITION = `1`
| COUNTRY_EDITION_V6 = `12`
| REGION_EDITION_REV0 = `7`
| REGION_EDITION_REV1 = `3`
| CITY_EDITION_REV0 = `6`
| CITY_EDITION_REV1 = `2`
| CITY_EDITION_REV1_V6 = `30`
| ORG_EDITION = `5`
| ISP_EDITION = `4`
| ASNUM_EDITION = `9`
| ASNUM_EDITION_V6 = `21`
| PROXY_EDITION = `8`
| NETSPEED_EDITION = `11`
| IPV6_EDITIONS = ``(`12`,` 21`,` 30`)``
| CITY_EDITIONS = ``(`6`,` 2`,` 30`)``
| REGION_EDITIONS = ``(`7`,` 3`)``
| REGION_CITY_EDITIONS = ``(`7`,` 3`,` 6`,` 2`,` 30`)``
| SEGMENT_RECORD_LENGTH = `3`
| STANDARD_RECORD_LENGTH = `3`
| ORG_RECORD_LENGTH = `4`
| MAX_RECORD_LENGTH = `4`
| MAX_ORG_RECORD_LENGTH = `300`
| FULL_RECORD_LENGTH = `50`
| US_OFFSET = `1`
| CANADA_OFFSET = `677`
| WORLD_OFFSET = `1353`
| FIPS_RANGE = `360`
| ENCODING = ``'``iso-8859-1``'``
| __package__ = ``'``pygeoip``'``

Variables Details

  ### DMA_MAP Value:
      {500: 'Portland-Auburn, ME',
       501: 'New York, NY',
       502: 'Binghamton, NY',
       503: 'Macon, GA',
       504: 'Philadelphia, PA',
       505: 'Detroit, MI',
       506: 'Boston, MA',
       507: 'Savannah, GA',
      ...

  ### COUNTRY_CODES Value:
      ('',
       'AP',
       'EU',
       'AD',
       'AE',
       'AF',
       'AG',
       'AI',
      ...

  ### COUNTRY_CODES3 Value:
      ('',
       'AP',
       'EU',
       'AND',
       'ARE',
       'AFG',
       'ATG',
       'AIA',
      ...

  ### COUNTRY_NAMES Value:
      ('',
       'Asia/Pacific Region',
       'Europe',
       'Andorra',
       'United Arab Emirates',
       'Afghanistan',
       'Antigua and Barbuda',
       'Anguilla',
      ...

  ### CONTINENT_NAMES Value:
      ('--',
       'AS',
       'EU',
       'EU',
       'AS',
       'AS',
       'NA',
       'NA',
      ...